
*	************************************************************************
* 	File-Name: 		JW_JW_CQ_Replication-Maps.do
*	Log-file:		JW_JW_CQ_Replication-Maps.log
*	Date:  			10 Sep 2015
*	Author: 		Jeremy Wallace
*	Data Used:  	1.  map-data.dta
*					2.	prefcoord.dta [Original from from www.gadm.org. At time of creating the replication file, the URL is: http://biogeo.ucdavis.edu/data/gadm2.7/shp/CHN_adm.zip]
*					  
*
*	Data Location	"C:\Users\jlw397\Dropbox\Anti-Japan Protest\Data"
*	.do Location	"C:\Users\jlw397\Dropbox\Anti-Japan Protest\Analysis"
*
*	Output Files:	1. 	augprotest_map.png 			[& .tif creation is commented out; also in black and white (BW) and color]
*					2. 	sepprotest_map.png 			[& .tif creation is commented out; also in black and white (BW) and color]
*					3. 	sepprotest_pre18_map.png 	[& .tif creation is commented out; also in black and white (BW) and color]
*					4. 	protest_number_map.png
*
*
*	Purpose:   		Replicating maps from Wallace Weiss 2015
*	
*	Code structure:	0.	Installation [one time]
*					1.  Download Map Files
*					2. 	Maps
*	************************************************************************

*	************************************************************************
*   0. Installation of add-ons [one time]
*

*ssc install shp2dta
*ssc install spmap


*	************************************************************************
*   1. Download Map files [included prefcoord.dta allows this step to be skipped]
*

*cd "C:\YOUR FOLDER HERE\CHN_adm"
*shp2dta using CHN_adm2, database(prefdb) coordinates(prefcoord) genid(id1)


*	************************************************************************
*   2. Maps (Reds and Grays) .png (.tif creation commented out)
*	

clear
*cd "C:\YOUR FOLDER HERE\"
cd "C:\Users\jlw397\Dropbox\Anti-Japan Protest\Replication"

capture log close
log using "JW_JW_CQ_Replication-Maps", replace

use map-data, clear

spmap augprotest using "prefcoord.dta", id(id1) fcolor(Reds) ndfcolor(gs15) ndocolor(white) legend(off) title("August Protest")
graph export "augprotest_map.png", replace 
*graph export "augprotest_map.tif", width(1800) replace
spmap sepprotest using "prefcoord", id(id1) fcolor(Reds) ndfcolor(gs15) ndocolor(white) legend(off) title("September Protest")
graph export "sepprotest_map.png", replace
*graph export "sepprotest_map.tif", width(1800) replace
spmap sepprotestpre18 using "prefcoord", id(id1) fcolor(Reds) ndfcolor(gs15) ndocolor(white) legend(off) title("September Crescendo (pre-18th)")
graph export "sepprotest_pre18_map.png", replace
*graph export "sepprotest_pre18_map.tif", width(1800)replace
spmap protestnumber using "prefcoord", id(id1) fcolor(Reds) ndfcolor(gs15) ndocolor(white) title("Protest Number") legstyle(2)
graph save "protest_number_map.png", replace

spmap augprotest using "prefcoord.dta", id(id1) clmethod(unique) fcolor(Greys2) ocolor(gs5 gs5) ndfcolor(gs15) ndocolor(white) legend(off) title("August Protest")
graph export "augprotest_mapBW.png", replace 
*graph export "augprotest_mapBW.tif", width(1800) replace 
spmap sepprotest using "prefcoord", id(id1) clmethod(unique) fcolor(Greys2) ocolor(gs5 gs5) ndfcolor(gs15) ndocolor(white) legend(off) title("September Protest")
graph export "sepprotest_mapBW.png", replace 
*graph export "sepprotest_mapBW.tif", width(1800) replace 
spmap sepprotestpre18 using "prefcoord", id(id1) clmethod(unique) fcolor(Greys2) ocolor(gs5 gs5) ndfcolor(gs15) ndocolor(white) legend(off) title("September Crescendo (pre-18th)")
graph export "sepprotest_pre18_mapBW.png", replace 
*graph export "sepprotest_pre18_mapBW.tif", width(1800) replace 


log close
