
*	************************************************************************
* 	File-Name: 		JW_JW_CQ_Replication-Tables.do
*	Log-file:		JW_JW_CQ_Replication-Tables.log
*	Date:  			10 Sep 2015
*	Author: 		Jeremy Wallace
*	Data Used:  	1.	replication.dta  	
*
*	Data Location	"~\Replication"
*
*	Output Files:	1. 	table1.rtf			[summary statistics]
*					2. 	table2.rtf			[aug. protest analysis]
*					3.  table3.rtf			[sep. protest analysis]
*					4.  apptable1-5.rtf 	[appendix tables]
*					5. 	Protest_List.csv	
*					6. 	fig1.png			[Figure 1]
*					7. 	dailytotal.png		[Appendix Figure 1]
*
*					*. 	augmap.png			[see JW_JW_CQ_Replication-Maps.do]
*					*.	totalmap.png		[see JW_JW_CQ_Replication-Maps.do]
*					*. 	augtotalmap.png		[see JW_JW_CQ_Replication-Maps.do]
*
*
*
*	Purpose:   		.do file for replication
*	Requires:		estout 	
*
*	Code structure:	0. 	Software installation
*					1. 	Folder and Open Data
*					2. 	T-tests
*					3.	Tables 1-3 and Appendix Tables
*					4. 	Graphs (see also the JW_JW_CQ_Replication-Maps.do file)
*					5. 	Daily Total figure and table

*	************************************************************************

*	************************************************************************
*   0. Software installation
*

*ssc install estout


*	************************************************************************
*   1. Folder and Open Data
*



clear
*cd "C:\YOUR FOLDER HERE\"
cd "C:\Users\jlw397\Dropbox\Anti-Japan Protest\Replication"

capture log close
log using "JW_JW_CQ_Replication-Tables", replace

use "replication.dta", clear



*	************************************************************************
*   2. T tests, aug 19 and sep 18. 
*

ttest gdpindex, by(augprotest)   			/* -, slower growing = more protests  (small effect) */
ttest gdpindex, by(aug19protest) 			/* -, slower growing = more protests  (small effect) */
ttest gdpindex, by(sep18protest) 			/* -, slower growing = more protests (vsmall effect) */

ttest lgdppc, by(augprotest) 				/* +, richer = more protests  (large effect) */
ttest lgdppc, by(aug19protest) 				/* +, richer = more protests  (large effect) */
ttest lgdppc, by(sep18protest)				/* +, richer = more protests  (small effect) */

ttest collegestudentspc, by(augprotest) 	/* +, more students = more protests  (huge effect) */
ttest collegestudentspc, by(aug19protest) 	/* +, more students = more protests  (huge effect) */
ttest collegestudentspc, by(sep18protest)	/* +, more students = more protests  (vsmall effect) */

ttest ltotalpop, by(augprotest) 			/* +, more people  = more protests  (large effect) */
ttest ltotalpop, by(aug19protest) 			/* +, more people  = more protests  (large effect) */
ttest ltotalpop, by(sep18protest)			/* +, more people  = more protests  (small effect) */

ttest studentshare, by(augprotest) 			/* +, more students = more protests  (huge effect) */
ttest studentshare, by(sepprotest) 			/* +, more students = more protests  (huge effect) */
ttest collegestudentspc, by(sepprotest) 	/* +, more students = more protests  (huge effect) */

* A nice illsutration
table augprotest if avgeducation > 10
table augprotest if avgeducation > 9 & avgeducation < 10
table augprotest if avgeducation > 8 & avgeducation < 9
table augprotest if avgeducation < 8


*	************************************************************************
*   3. Tables
*

*	************************************************************************
* 	TABLE 1

eststo clear

estpost summarize augprotest sepprotestpre18 sepprotest anyoccupy anypatriotic fullyoccupy anyantijapan gdpindex lgdppc collegestudentspc ltotalcensuspop ltotalcensusmigrants antshare minorityshare migrantshare longterm lexports_2011
esttab using table1.rtf, replace compress nonum cells("count mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") noobs label

*	************************************************************************
* 	TABLE 2

eststo clear

eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anyoccupy anypatriotic, robust
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc fullyoccupy anyantijapan, robust
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic, robust
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc lgdppc, robust
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic longterm, robust 

esttab using table2.rtf, replace compress												///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 							///
		title(Table 2. Early Wave Protest Correlates)									///
		nonumbers mtitles("Model 1" "Model 2" "Model 3" "Model 4" "Model 5")	
		
*	************************************************************************
* 	TABLE 3
		
eststo clear
		
eststo: quietly logit sepprotestpre18 	gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc lgdppc, robust
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare, robust
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare longterm, robust 
eststo: quietly logit sepprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc fullyoccupy anyantijapan, robust
eststo: quietly logit sepprotest 		ltotalcensuspop collegestudentspc minorityshare, robust
eststo: quietly logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare longterm, robust

esttab using table3.rtf, replace compress								///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 			///
		title(Table 3. September Protest Correlates)					///
		nonumbers mtitles("Model 6-Pre 18" "Model 7-Pre 18" "Model 8-Pre 18" "Model 9" "Model 10" "Model 11")	
		
eststo clear


*	************************************************************************
* 	Appendix Table 1: Large Protests

logit largeprotest 			ltotalcensuspop collegestudentspc minorityshare, robust 
logit auglargeprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic, robust
logit seplargeprotest 		ltotalcensuspop collegestudentspc minorityshare, robust 


eststo: quietly logit largeprotest 			ltotalcensuspop collegestudentspc minorityshare, robust 
eststo: quietly logit auglargeprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic, robust
eststo: quietly logit seplargeprotest 		ltotalcensuspop collegestudentspc minorityshare, robust 

esttab using apptable1.rtf, replace compress									///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 					///
		title(Appendix Table 1. September Protest Correlates)					///
		nonumbers mtitles("Large Protests" "Aug. Large Protests" "Sep. Large Protests")	
		
eststo clear


*	************************************************************************
* 	Appendix Table 2: Exports  [[No effect at this time; exports correlate with city size; after controlling for total pop, no effect.]]

logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	lexports_2011, robust 
logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			lexports_2011, robust 
logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare 								lexports_2011, robust 

eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	lexports_2011, robust 
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			lexports_2011, robust 
eststo: quietly logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare 								lexports_2011, robust 

esttab using apptable2.rtf, replace compress									///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 					///
		title(Appendix Table 2. Exports Do Not Affect Protest Likelihood)					///
		nonumbers mtitles("August Protests" "Sep. Pre-18 Protests" "All September Protests")	
		
eststo clear

*	************************************************************************
* 	Appendix Table 3: 2011 FDI No Effects

logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	lfdi_2011	, robust
logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			lfdi_2011	, robust
logit sepprotest 		ltotalcensuspop collegestudentspc minorityshare 								lfdi_2011	, robust

eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	lfdi_2011	, robust
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			lfdi_2011	, robust
eststo: quietly logit sepprotest 		ltotalcensuspop collegestudentspc minorityshare 								lfdi_2011	, robust

esttab using apptable3.rtf, replace compress									///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 					///
		title(Appendix Table 3. FDI Does Not Affect Protest Likelihood)			///
		nonumbers mtitles("August Protests" "Sep. Pre-18 Protests" "All September Protests")	
		
eststo clear

*	************************************************************************
* 	Appendix Table 4: 1989 Protests No Effects

logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic	protest1989	, robust 
logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare			protest1989	, robust 
logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare									protest1989	, robust 

logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	protestdays1989, robust 
logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			protestdays1989, robust 
logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare 			 					protestdays1989, robust 



eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic	protest1989	, robust 
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare			protest1989	, robust 
eststo: quietly logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare									protest1989	, robust 
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic 	protestdays1989, robust 
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare 			protestdays1989, robust 
eststo: quietly logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare 			 					protestdays1989, robust 

esttab using apptable4.rtf, replace compress									///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 					///
		title(Appendix Table 4. 1989 Protests Do Not Affect Protest Likelihood)			///
		nonumbers mtitles("August Protests" "Sep. Pre-18 Protests" "All September Protests" "Aug. Protests--Days" "Sep. Pre-18 Protests--Days" "All September Protests--Days")	
		
eststo clear

*	************************************************************************
* 	Appendix Table 5: Any Protest & 2010 Protests

logit anyprotest 		gdpindex ltotalcensuspop collegestudentspc migrantshare minorityshare, robust 
* gdpindex -; ltotalcensuspop +;  collegestudentspc +; migrantshare +; minorityshare -; antshare 0; longterm 0; anypatriotic 0
logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic	protest2010	, robust 
logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare			protest2010	, robust 
logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare									protest2010	, robust 
* n.b. 2010 protest does negatively affect september protests [although this is likely a rarity vs. broad phenomenon.]

eststo: quietly logit anyprotest 		gdpindex ltotalcensuspop collegestudentspc migrantshare minorityshare, robust 
eststo: quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc anypatriotic	protest2010	, robust 
eststo: quietly logit sepprotestpre18 	ltotalcensuspop collegestudentspc migrantshare minorityshare antshare			protest2010	, robust 
eststo: quietly logit sepprotest	 	ltotalcensuspop collegestudentspc minorityshare									protest2010	, robust 

esttab using apptable5.rtf, replace compress									///
		se(2) star(* 0.10 ** 0.05 *** 0.01) pr2(2) b(2) label 					///
		title(Appendix Table 5. Any Protest and 2010 Anti-Japanese Protest Locales)					///
		nonumbers mtitles("Any Protest" "Aug. Protest" "Sep. Pre-18 Protest" "All September Protests")	
		
eststo clear


*	************************************************************************
*   4. Graphs
*

quietly logit augprotest 		gdpindex ltotalcensuspop ltotalcensusmigrants collegestudentspc, robust 
margins, at(collegestudentspc=(0.1(0.1)12)) atmeans 
marginsplot, level(90) recastci(rline) 
graph export fig1.png, replace



*	************************************************************************
*   5. Daily Total and Protest List
*

preserve

reshape long protestdate, i(dijishicitycode)
keep if protestdate != ""
gen eventdate = date(protestdate, "MDY")
format eventdate %td
table eventdate

tsset dijishicitycode eventdate

sort eventdate dijishicitycode _j

egen dailytotal = total(protest), by(eventdate)
scatter dailytotal eventdate, msize(large)
graph export "dailytotal.png", replace

*g day = day(eventdate)
*g month = month(eventdate)

keep dijishicitycode _j province cityname eventdate
outsheet using "Protest_List.csv", comma replace


restore

log close

